==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/EMAILCONDITIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EMAILCONDITIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EMAILCONDITIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMAILCONDITIONPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMAILCONDITIONID_Type", propOrder = {
    "emailconditionpk"
})
public class EMAILCONDITIONID_Type {

    @XmlElement(name = "EMAILCONDITIONPK", required = true)
    protected String emailconditionpk;

    /**
     * Obtient la valeur de la propriété emailconditionpk.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMAILCONDITIONPK() {
        return emailconditionpk;
    }

    /**
     * Définit la valeur de la propriété emailconditionpk.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMAILCONDITIONPK(String value) {
        this.emailconditionpk = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/EMAILCONDITIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EMAILCONDITIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EMAILCONDITIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMAILCONDITIONPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMAILCONDITIONID_Type", propOrder = {
    "emailconditionpk"
})
public class EMAILCONDITIONID_Type {

    @XmlElement(name = "EMAILCONDITIONPK", required = true)
    protected String emailconditionpk;

    /**
     * Gets the value of the emailconditionpk property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMAILCONDITIONPK() {
        return emailconditionpk;
    }

    /**
     * Sets the value of the emailconditionpk property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMAILCONDITIONPK(String value) {
        this.emailconditionpk = value;
    }

}
